import type { Priority } from './constants/priorities'

import type {IAbstract} from './IAbstract'
import type {IUser} from './IUser'
import type {ILabel} from './ILabel'
import type {IAttachment} from './IAttachment'
import type {ISubscription} from './ISubscription'
import type {IList} from './IList'
import type {IBucket} from './IBucket'

import type {IRepeats} from '@/types/IRepeats'

export const TASK_REPEAT_MODES = {
	'REPEAT_MODE_DEFAULT': 0,
	'REPEAT_MODE_MONTH': 1,
	'REPEAT_MODE_FROM_CURRENT_DATE': 2,
} as const

export type TaskRepeatMode = typeof TASK_REPEAT_MODES[keyof typeof TASK_REPEAT_MODES] 

export interface ITask /* extends IAbstract */ {
	id: number
	title: string
	description: string
	done: boolean
	doneAt: Date | null
	priority: Priority
	labels: ILabel[]
	assignees: IUser[]

	dueDate: Date | null
	startDate: Date | null
	endDate: Date | null
	repeatAfter: number | IRepeats
	repeatFromCurrentDate: boolean
	repeatMode: TaskRepeatMode
	reminderDates: Date[]
	parentTaskId: ITask['id']
	hexColor: string
	percentDone: number
	relatedTasks: { [relationKind: string]: ITask } // FIXME: use relationKinds
	attachments: IAttachment[]
	identifier: string
	index: number
	isFavorite: boolean
	subscription: ISubscription

	position: number
	kanbanPosition: number

	createdBy: IUser
	created: Date
	updated: Date

	listId: IList['id'] // Meta, only used when creating a new task
	bucketId: IBucket['id']
}