import {objectToCamelCase} from '@/helpers/case'
import {omitBy, isNil} from '@/helpers/utils'
import type {Right} from '@/modelTypes/constants/rights'
import type {IAbstract} from '@/modelTypes/IAbstract'

export default class AbstractModel<Model extends IAbstract = IAbstract> {

	/**
	 * The max right the user has on this object, as returned by the x-max-right header from the api.
	 */
	maxRight: Right | null = null

	/**
	 * The abstract constructor takes an object and merges its data with the default data of this model.
	 */
	constructor(data : Object = {}) {
		data = objectToCamelCase(data)

		console.log('AbstractModel:')
		console.log(this.title)
		console.log(this.defaults().title)
		console.log(data.title)
		console.log(omitBy(data, isNil).title)

		// Put all data in our model while overriding those with a value of null or undefined with their defaults
		Object.assign(
			this,
			this.defaults(),
			omitBy(data, isNil),
		)
		console.log(this.title)
	}

	/**
	 * Default attributes that define the "empty" state.
	 */
	defaults(): Model {
		return {} as Model
	}
}